/* newsleech.h - general definitions 
   Copyright (C) 2000 Rik Snel <snel@phys.uu.nl>
   Parts copyright by Eric S. Raymond and the Free Software Foundation

   This file is part of newsleech.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. 
*/

extern int verbose;

/* Mostly disable gettext stuff for the moment */
#ifdef HAVE_GNUGETTEXT
#define _(string) gettext (string)
#else
#define _(string) string
#endif

/* The following struct's illustrate the main idea behind this program,
   below is serverinfo. Each server contains groups and each group contains 
   'postings'. Each posting consist of at least one article. We associate 
   a filename (default: stdout) with each posting where the posting will be 
   sent. (a binary posting, for example, contains more than one article, but
   we want to have it in one file.
*/  
struct postinginfo {
	int *articles;  /* ordened array of articles in posting	       */
	int count;	/* number of articles in posting               */
	char action;    /* 'p' pipe to *pipeto, 'f' save to *filename  */ 
			/* 's' dump to stdout			       */
	char *filename; /* file where the posting will be saved        */
	char *pipeto;   /* unix command to which posting will be piped */
	char *command;	/* ARTICLE, BODY, HEAD, XHDR                   */
	char *header;	/* first argument to XHDR                      */
};

struct groupinfo {
	char *name;	/* name of the group                              */
	struct postinginfo *postings; /* info about postings              */
	int count;	/* number of postings to be visited in this group */
	int first; 	/* message number of first message in the group   */
	int last;       /* message number of last message in the group    */
	int total;	/* total number of messages in group              */
};

struct serverinfo {
	char *name;			/* Name of the server (or IP addr) */
	int port;			/* port number, default 119 (nntp) */
	char *user;
	char *pass;
	int interval;		        /* retry interval on too many conns*/
	int aretry;			/* number of article retreive ret. */
	struct groupinfo *groups;	/* info about groups		   */
	int count;			/* number of groups in groupinfo   */	
};

struct rootnodeinfo {
	struct serverinfo *servers;	/* info about servers		   */
	int count;			/* number of servers in groupinfo  */	
};

