%{
#define YY_DECL int yylex YY_PROTO(( int *linenum, int *option, char* *optarg ))
#include <string.h>
#define MAX_INCLUDE_DEPTH 10
YY_BUFFER_STATE include_stack[MAX_INCLUDE_DEPTH];
int include_stack_ptr = 0;

void push_buffer_state(FILE *fp) {
	if (include_stack_ptr >= MAX_INCLUDE_DEPTH) {
		fprintf(stderr, "Includes nested to deeply, increase MAX_INCLUDE_DEPTH in parser.yy\n");
		exit(1);
	}
	include_stack[include_stack_ptr] = YY_CURRENT_BUFFER;
	include_stack_ptr++;
	yyin = fp;
	yy_switch_to_buffer(yy_create_buffer(yyin, YY_BUF_SIZE));
}

void pop_buffer_state() {
	include_stack_ptr--;
	yy_delete_buffer(YY_CURRENT_BUFFER);
	yy_switch_to_buffer(include_stack[include_stack_ptr]);
}
%}
DIGIT		[0-9]
SORG		[[:alnum:]](\.[[:alnum:]])*
%x	keyword
%x	argument
%option nounput

%%
	int len;
	BEGIN(keyword);
	*optarg=NULL;

<keyword>^server {
	*option = 's';
	BEGIN(argument);
	}

<keyword>^group	{
	*option = 'g';
	BEGIN(argument);
	}

<keyword>^article {
	*option = 'a';
	return(1);
	}

<keyword>^body	{
	*option = 'b';
	return(1);
	}

<keyword>^header	{
	*option = 'e';
	return(1);
	}

<keyword>^list	{
	*option = 'l';
	BEGIN(argument);
	}
	

<keyword>^port	{
	*option = 'p';
	BEGIN(argument);
	}

<keyword>^alias	{
	*option = '9';
	BEGIN(argument);
	}
	
<argument>\".*\"	{
	len = strlen(yytext) - 1;
	yytext++; 		/* cut out the first \" */
	*(yytext+len-1) = 0;	/* cut out the last \" */
	*optarg = malloc(len);
	*optarg=strcpy(*optarg, yytext);
	BEGIN(keyword);
	return(1);
	}

<argument>\'.*\'	{
	len = strlen(yytext) - 1;
	yytext++; 		/* cut out the first \' */
	*(yytext+len-1) = 0;	/* cut out the last \' */
	*optarg = malloc(len);
	*optarg=strcpy(*optarg, yytext);
	BEGIN(keyword);
	return(1);
	}

<argument>[^\n\t ]*	{
	len = strlen(yytext) + 1;
	*optarg = malloc(len);
	*optarg=strcpy(*optarg, yytext);
	BEGIN(keyword);
	return(1);
	}

<argument>\n {
	return(2);
	}
	
<keyword>^username	{
	*option = '3';
	BEGIN(argument);
	}

<keyword>^password	{
	*option = '4';
	BEGIN(argument);
	}

<keyword>^range	{
	*option = 'r';
	BEGIN(argument);
	}

<keyword>^interval {
	*option = 'i';
	BEGIN(argument);
	}

<keyword>^aretry {
	*option = 'R';
	BEGIN(argument);
	}

<keyword>^end {
	return(4);
	}
	
<keyword>^stdout	{
	*option = '2';
	BEGIN(argument);
	}

<keyword>^filename {
	*option = 'f';
	BEGIN(argument);
	}

<keyword>^pipeto	{
	*option = 't';
	BEGIN(argument);
	}

<keyword>^dummy {
	*option = '5';
	return(1);
	}
	
<*>[ \t]	
	
<keyword>\n {
	*linenum += 1;
	}

<keyword>^#.*$


<*>.	{
	return(3);
	}

%%

/*main(){
	int option;
	char *optarg;
	while (1) {
		switch(yylex(&option, &optarg)) {
			case 0:
				printf("scriptended\n");
				exit(0);
				break;
			case 3:
				printf("parse error\n");
				exit(1);
				break;
			case 2:
				printf("option requires argument\n");
				exit(1);
				break;
			case 1:
				printf("option is %c, met arg %s\n", (char)option, optarg);
				break;
		}
	}
	
}*/
