/* tcp.c - basic TCP functions for use with newsleech
   Copyright (C) 2000 Rik Snel <snel@phys.uu.nl>
   Parts copyright by Eric S. Raymond and the Free Software Foundation

   This file is part of newsleech.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. 
*/
/* The tcp functions ar adaptations of those found in fetchmail */

#include<stdio.h>
#include<unistd.h>
#include<varargs.h>
#include<netdb.h>
#include<string.h>
#include<sys/socket.h>
#include<sys/types.h>
#include<netinet/in.h>

#include "config.h"

#include "newsleech.h"
#include "tcp.h"

int open_tcp_connection(char *server, int port) {
	int sock, error;
	struct hostent *newshost;
	struct sockaddr_in newshost_in;
	
	if (verbose & 2) fprintf(stderr, "Looking up %s.\n", server);
	newshost = gethostbyname(server);
	if (!newshost) {
		fprintf(stderr, "Error %d looking up %s.\n", h_errno, server);
		return(-2);
	}
	
	newshost_in.sin_family = AF_INET;
	newshost_in.sin_addr.s_addr = *(u_long *)newshost->h_addr_list[0];
	newshost_in.sin_port = htons(port);

	sock = socket(PF_INET, SOCK_STREAM, 0);
	if (sock == -1) {
		fprintf(stderr, "Error creating socket.\n");
		return(-2);
	}
	
	if (verbose & 2) fprintf(stderr, "Trying to open connection...\n");
	error = connect(sock, (struct sockaddr *)&newshost_in, sizeof(newshost_in));
	if (error == -1) {
		fprintf(stderr, "Error opening connection.\n");
		close(sock);
		return(-2);
	}
	if (verbose & 2) fprintf(stderr, "TCP connection opened to port %d of %s.\n", port, server);
	return(sock);
}	

void close_tcp_connection(int sock) {
	if (verbose & 2) fprintf(stderr, "Closing TCP connection.\n");
	close(sock);
}

int tcp_socket_readline(int sock, char *buf, int length) {
	char *newline, *bp = buf;
	int n;
	if (--length < 1) return(-1);
	do {
		if ((n = recv(sock, bp, length, MSG_PEEK)) <= 0) return(-1);
		if ((newline = memchr(bp, '\n', n)) != NULL)
			n = newline - bp + 1;
		if ((n = read(sock, bp, n)) == -1) return(-1);
		bp += n;
		length -= n;
	} while (!newline && length);
	*bp = '\0';
	return(bp-newline);
}

int tcp_socket_write(int sock, char *buf, int length) {
	int n, wrlength;
	while(length) {
		n = write(sock, buf, length);
		if (n <= 0) return(-1);
		length -= n;
		wrlength += n;
		buf += n;
	}
	return(wrlength);
}

int tcp_socket_printf(sock, format, va_alist)
int sock;
char *format;
va_dcl {
	va_list ap;
	char buf[8192];
	
	va_start(ap);
#ifdef HAVE_VSNPRINTF
	vsnprintf(buf, sizeof(buf), format, ap);
#else
	vsprintf(buf, format, ap);
#endif
	va_end(ap);
	return(tcp_socket_write(sock, buf, strlen(buf)));
}
